diff --git a/commands.go b/commands.go
index dc97f28..8de84b1 100644
--- a/commands.go
+++ b/commands.go
@@ -354,8 +354,8 @@ func move(user *gumble.User, channel string) {
}
}
-// move performance !joinme functionality. Found the channel and move the bot. The bot don't move
-// if it already play music to people
+// joinMe performs !joinme functionality. Finds the channel and moves the bot.
+// The bot does not move if it is already playing audio to others.
func joinMe(user *gumble.User) {
if dj.audioStream.IsPlaying() && len(dj.client.Self.Channel.Users) > 1 {
user.Send(PEOPLE_ARE_LISTENING_TO_ME)
diff --git a/config.gcfg b/config.gcfg
index 527d07a..5816a63 100644
--- a/config.gcfg
+++ b/config.gcfg
@@ -106,7 +106,7 @@ HelpAlias = "help"
# DEFAULT VALUE: "volume"
VolumeAlias = "volume"
- Alias used for join a user
+ Alias used for joinme
# DEFAULT VALUE : "joinme"
JoinMeAlias = "joinme"
@@ -214,8 +214,8 @@ AdminVolume = false
AdminMove = true
# Make joinme a admin command?
-# DEFUALT VALUE: true
-AdminJoinMe = false
+# DEFAULT VALUE: true
+AdminJoinMe = true
# Make reload an admin command?
# DEFAULT VALUE: true
diff --git a/strings.go b/strings.go
index fff9272..5099637 100644
--- a/strings.go
+++ b/strings.go
@@ -98,8 +98,8 @@ const SHUFFLE_ACTIVATED_ERROR_MESSAGE = "Automatic shuffle is already activated.
// Message shown to user when they attempt to disable automatic shuffle while it's already deactivated
const SHUFFLE_DEACTIVATED_ERROR_MESSAGE = "Automatic shuffle is already deactivated."
-// Message show to user when they attempt to move it and it is already playing music to people
-const PEOPLE_ARE_LISTENING_TO_ME = "I'm already busy."
+// Message shown to user when they attempt to move the bot and it is already playing audio to others.
+const PEOPLE_ARE_LISTENING_TO_ME = "Users in another channel are listening to me."
// Message shown to channel when a song is added to the queue by a user.
const SONG_ADDED_HTML = `
@@ -154,7 +154,7 @@ const HELP_HTML = `
!shuffleon - An admin command that enables auto shuffling.
!shuffleoff - An admin command that disables auto shuffling.
!move - Moves MumbleDJ into channel if it exists.
-!joinme - Move into your channel (MP)
+!joinme - Moves MumbleDJ into your current channel if not playing audio to someone else.
!reload - Reloads mumbledj.gcfg configuration settings.
!setcomment - Sets the comment for the bot.
!numcached
- Outputs the number of songs cached on disk.